#
# spec file for package vmmlib
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org
#


Name:           vmmlib
Version:        1.8.0
Release:        5.4
Summary:        A templatized C++ vector and matrix math library
License: GPL-2.0
Group:          System/Libraries
# Original Project: http://vmml.github.io/vmmlib/
Url:            https://eyescale.github.io/
Source0:        https://github.com/Eyescale/vmmlib/archive/1.8.0.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://github.com/Eyescale/CMake/archive/master.tar.gz#/CMake-common_git20150515.tar.gz
# PATCH-FIX-UPSTREAM CMakeLists.diff avvissu@yandex.ru -- Support cblas
#Patch0:         CMakeLists.diff
# PATCH-FIX-UPSTREAM doxygen.patch avvissu@yandex.ru -- Fix build error: need administrative privileges
Patch1:         CMake_doxygen.patch
# PATCH-FIX-UPSTREAM include.patch avvissu@yandex.ru -- Remove Buildyard project
Patch2:         vmmlib-1.8.0_include.patch
BuildRequires:  blas-devel
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
#BuildRequires:  cblas-devel
BuildRequires:  lapack-devel
BuildRequires:  pkgconfig
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
vmmlib is a vector and matrix math library implemented using C++ templates.
Its basic functionality includes a vector and a matrix class, with additional
functionality for the often-used 3d and 4d vectors and 3x3 and 4x4 matrices.
More advanced functionality include solvers, frustum computations and frustum
culling classes, and spatial data structures.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       boost-devel

%description    devel
This package contains header files and libraries needed to develop 
application that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
A templatized C++ vector and matrix math library
...
API Documentation for %{name}.

%prep
%setup -q -a1
mv CMake-common* CMake/common
#%patch0 -p1
%patch2 -p1
pushd CMake/common
%patch1 -p1
popd

# Do not compile in DATE and TIME
grep -rl 'HTML_TIMESTAMP' . | \
	xargs --no-run-if-empty --verbose \
	sed -i '/^HTML_TIMESTAMP/s/YES/NO/'

%build
%cmake \
    -DCMAKE_BUILD_TYPE=Release

make %{?_smp_mflags}
make %{?_smp_mflags} doxygen

%install
%make_install -C build

mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/%{name}/{README.md,AUTHORS,LICENSE.txt,ACKNOWLEDGEMENTS,doc/API} \
%{buildroot}%{_docdir}/%{name}

%fdupes %{buildroot}%{_includedir}
%fdupes -s %{buildroot}%{_datadir}

%check
#make test -C build

%files devel
%defattr(-, root, root)
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}

%files doc
%defattr(-,root,root)
%{_docdir}/%{name}

%changelog
* Sat May 16 2015 avvissu@yandex.ru
- Update to 1.8.0:
  * provide option to find project via find_file
  * added support for snapshot module
  * remove OSS package targets from CommonCPack and use less disk
    pace for non-OSS packages
  * added TUVOK library
- Use fork instead of the original project: change url
- Add doc: Doxygen and other documentation
- Fix for RPMLINT W: Do not compile in DATE and TIME
- Use %%%%cmake macro instead of cmake
- Add check for duplicates, remove them and make symlinks
- Spec file cleanup
* Thu Oct 30 2014 avvissu@yandex.ru
- Comment BuildRequires: f2c
- Spec file cleanup
* Sat Dec 21 2013 avvissu@yandex.ru
- Initial Release 1.6.2
